#
# spec file for package linphoneqt
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   linphone
Name:           linphoneqt
Version:        4.3.2
Release:        bp154.1.48
Summary:        Qt interface for Linphone
License:        GPL-3.0-or-later
Group:          Productivity/Telephony/SIP/Clients
URL:            https://linphone.org/technical-corner/linphone
Source:         https://gitlab.linphone.org/BC/public/linphone-desktop/-/archive/%{version}/%{_name}-desktop-%{version}.tar.bz2
Source1:        %{_name}.appdata.xml
# PATCH-FIX-OPENSUSE linphoneqt-fix-no-git.patch -- Fix building out-of-git.
Patch0:         linphoneqt-fix-no-git.patch
# PATCH-FIX-OPENSUSE https://aur.archlinux.org/cgit/aur.git/plain/0002-remove-bc_compute_full_version-usage.patch?h=linphone-desktop
Patch1:         linphoneqt-0002-remove-bc_compute_full_version-usage.patch
BuildRequires:  Mesa-libGLESv2-devel
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core) >= 5.12
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5QuickControls2)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5TextToSpeech)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(linphone) >= 5.0.0
BuildRequires:  pkgconfig(mediastreamer) >= 5.0.0

%description
Linphone is a Web phone with a Qt interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

%package -n %{_name}
Summary:        Web Phone
Group:          Productivity/Telephony/SIP/Clients
Requires:       liblinphone-data
Recommends:     %{_name}-cli
Obsoletes:      %{_name}-lang < %{version}

%description -n %{_name}
Linphone is a Web phone with a Qt interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

%prep
%autosetup -n %{_name}-desktop-%{version} -p1
cp %{SOURCE1} linphone.appdata.xml
touch linphone-sdk/CMakeLists.txt
mkdir -p build/linphone-sdk/desktop/{bin,share}

# Fix building out-of-git
echo '#define LINPHONE_QT_GIT_VERSION "${PROJECT_VERSION}"' >> linphone-app/src/config.h.cmake
# Hardcode linphoneqt version
echo "project(linphoneqt VERSION %{version})" > linphone-app/linphoneqt_version.cmake

%build
sed -i '/^add_custom_command/s@${CMAKE_INSTALL_PREFIX}/include/@%{buildroot}%{_includedir}/@;/^add_custom_command/s@${CMAKE_INSTALL_PREFIX}/lib/@%{buildroot}%{_libdir}/@' linphone-app/CMakeLists.txt
#fix install error for 4.3.2
if [[ %version = 4.3.2 ]]; then
    sed -i '/install(DIRECTORY.*linphone/d' linphone-app/cmake_builder/linphone_package/CMakeLists.txt
fi
%cmake \
  -DCMAKE_CXX_FLAGS="-fpermissive" \
  -DCMAKE_BUILD_TYPE=Release \
  -DLINPHONE_OUTPUT_DIR="$PWD" \
  -DENABLE_UPDATE_CHECK=OFF \
  -DENABLE_STRICT=OFF       \
  -DENABLE_STATIC=OFF
%cmake_build

%install
%cmake_install
install -Dpm 0644 linphone.appdata.xml \
  %{buildroot}%{_datadir}/metainfo/org.linphone.appdata.xml

rm %{buildroot}%{_bindir}/qt.conf
chmod a-x %{buildroot}%{_datadir}/applications/linphone.desktop

%files -n %{_name}
%license LICENSE.txt
%doc CHANGELOG.md README.md
%{_bindir}/linphone
%{_libdir}/libapp-plugin.so
%{_datadir}/linphone/
%{_datadir}/applications/linphone.desktop
%{_datadir}/icons/hicolor/*/apps/linphone.*
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/org.linphone.appdata.xml
%{_includedir}/LinphoneApp/

%changelog
* Mon Nov 22 2021 Klaus Kämpf <kkaempf@suse.com>
- Require liblinphone-data (bsc#1181746)
* Sun Nov 21 2021 Giacomo Comes <gcomes.obs@gmail.com> - 4.3.2
- Update to version 4.3.2:
  * ALSA volumes can be view/changed while being in call.
  * Remove constraints on actions (call/chat) that were based on friends capabilities.
  * Unblock secure group chat activation.
  * Unselect current contact if history call view is displayed.
  * Show chat actions in history view
* Mon Nov  8 2021 Giacomo Comes <gcomes.obs@gmail.com> - 4.3.1
- Update to 4.3.1:
  * A banner is shown when copying text.
  * Options to enable standard and secure chats.
  * Add tunnel support if build.
  * Overhaul of color managment and use monochrome images.
  * Change Contact Edit and SIP Addresses selections to start a standard chat or a secure one.
  * Call history button in the timeline panel.
  * Timeout of incoming call notification is now based on `inc_timeout`
  * More actions in contact edit panel (call/video call).
  * Allow to make a readonly variable in configuration (only for enabling chats yet).
* Tue Nov  2 2021 Giacomo Comes <gcomes.obs@gmail.com> - 4.3.0
- Update to 4.3.0:
  * Chat groups with administrator mode, participants management and devices display
  * Secure chat rooms for 1-1 and group chat using LIME end-to-end encryption
  * Ephemerals Chat rooms
  * LDAP integration: settings allow remote LDAP servers to be configured
  * Show subject in notifications for group chats
  * Chat area is no more fixed but adapts to content
  * Allow to hide or show the timeline panel
  * Allow to hide or show empty chat rooms in settings
  * Messages font can now be changed in settings
  * Echo calibration in settings view
  * Options to audio codec can be used and stored
  * A silence file have been added : `silence.mkv` and can be used to switch off some musics
* Tue Oct 19 2021 Giacomo Comes <gcomes.obs@gmail.com> - 4.2.5
- allow to build linphone-desktop-4.2.5 with liblinphone 5.0.x
* Thu Sep 30 2021 Giacomo Comes <gcomes.obs@gmail.com> - 4.2.5
- add BuildRequires:  pkgconfig(Qt5TextToSpeech)
* Fri Jul 30 2021 Giacomo Comes <gcomes.obs@gmail.com> - 4.2.5
- add BuildRequires:  Mesa-libGLESv2-devel
- add CMAKE_CXX_FLAGS=-fpermissive
* Sun Jul  4 2021 Giacomo Comes <gcomes.obs@gmail.com> - 4.2.5
- fixed several RPMLINT warning
* Thu Apr 15 2021 Luiz Angelo Daros de Luca <luizluca@tre-sc.jus.br>
- Added linphoneqt-0002-remove-bc_compute_full_version-usage.patch
  * Patch from ArchLinux to fix build without .git or linphone SDK
- Update to 4.2.5:
  * No changelog available.
- Update to 4.2.4:
  * Play DTMF when receiving it and show the Dialpad on outgoing
    call to allow sending DTMF
  * Update settings view to not deactivate transport but allow not
    binding port
  * Show all call logs by clicking on previously bar
  * Displaying names in UTF8
  * Keep unsend typed message in memory when changing of chat room
  * Log files have Qt logs
  * Add SOCI Sqlite3 library in Appimage
  * Use the more generic linphone folder and not Linphone for
    installation
  * Simplify build process to use install keyword
- Update to 4.2.3:
  * Add support to tel and callto protocols
  * Allow Pulseaudio to switch devices automatically. For example,
    it will mute all applications that have music when receive a
    call from Linphone.
  * Contact name can contain special characters
  * Avoid to reduce window if it is currently maximized when
    clicking on contacts
  * Cleaner use of Windows registries
- Update to 4.2.2:
  * Crash on Opus
* Tue Oct  6 2020 Benjamin Greiner <code@bnavigator.de>
- CMake Release build type to remove QML debugging boo#1140595
* Wed Jul 29 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.2.1:
  * See https://gitlab.linphone.org/BC/public/linphone-desktop/blob/4.2.1/CHANGELOG.md
- Update licence to GPLv3+.
- Rebase linphoneqt-fix-no-git.patch.
- Drop linphoneqt-fix-cmake-i18n.patch,
  linphoneqt-fix-qt-5.11.patch, fix-qm-generation.patch,
  linphoneqt-force-default-style.patch: fixed upstream.
- Drop linphoneqt-qt-5.9-fix-buttons.patch: no longer supported.
* Sat Aug 31 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add fix-qm-generation.patch to fix abort on startup (boo#1140595)
* Wed Aug 15 2018 sor.alexei@meowr.ru
- Add linphoneqt-fix-no-git.patch: Fix building out-of-git.
* Tue Aug 14 2018 sor.alexei@meowr.ru
- Change the RPM group to the more appropriate and precise
  Productivity/Telephony/SIP/Clients.
* Sun Aug 12 2018 sor.alexei@meowr.ru
- Add linphoneqt-force-default-style.patch: Force default theme
  style (commit 313aa68).
  This fixes issues with tabs reported in boo#1095273.
* Sat Aug  4 2018 sor.alexei@meowr.ru
- Add linphoneqt-qt-5.9-fix-buttons.patch: Fix button invisibility
  with Qt 5.9 (boo#1095273).
- Improve linphoneqt-fix-qt-5.11.patch: Add a fix for
  DefaultTranslator dealing with Qt 5.9 (commit d95f523).
* Thu Aug  2 2018 sor.alexei@meowr.ru
- Replace linphoneqt-fix-qt-5.10.patch with
  linphoneqt-fix-qt-5.11.patch, adding more fixes:
  * Try to support menu bar on Qt 5.10 (commit 5dd0161).
  * Fix ComboBox by importing named QtQuick.Controls (commit
    7f62ae9).
  * Do not use SignalSpy as click is emitted twice instead of one
    in Qt 5.11 (commit 8720931),
  * Avoid a crash in Calls with a bad binding (Qt 5.11) on
    ConferenceControls (commit 4f908ef).
- Do not bother installing the appstream file to
  /usr/share/appdata/ on openSUSE Leap 42.x or older.
* Thu Mar  8 2018 sor.alexei@meowr.ru
- Add linphoneqt-fix-qt-5.10.patch: Rename the icon property of
  TabButton to iconName (an issue with Qt 5.10 and the new icon
  property, commit ecaab0f, boo#1083654).
* Sun Sep 10 2017 sor.alexei@meowr.ru
- Add the missing libqt5-qtquickcontrols dependency (boo#1065173).
- Install the appstream file to the /usr/share/metainfo/ directory
  on openSUSE Leap 15.x or newer.
* Sun Sep 10 2017 sor.alexei@meowr.ru
- Add linphoneqt-fix-cmake-i18n.patch: Support new CMake versions
  for translations (commit e70c077).
* Fri Jul 21 2017 sor.alexei@meowr.ru
- Initial package.
